// -------------------------------------------------------------------
//                             EXNFES
//  This program reads an infeasible LP problem from an MPS file and
//  solves it using the primal simplex method.  Then, it analyzes the
//  row/column infeasibilities to generate an IIS (Irreducible Infeasible
//  Subset) of rows and columns.
// ------------------------------------------------------------------- 

#include <string.h>
#include <stdlib.h>
#include <math.h>
#include <assert.h>
#include "ekk_c_api.h"

void main()
{
    // Initialize OSL environment 
    EKKContext * env;
    env = ekk_initializeContext();

    // Create an OSL model "test" 
    EKKModel * test;
    test=ekk_newModel(env,NULL);

    // Set to print nonzero solutions only 
    int rtcod = ekk_setIsolmask(test,6);

    // Read model data from MPS file 
    rtcod = ekk_importModel(test,"box1.mps");

    // Scale the model data 
    rtcod = ekk_scale(test);

    // Solve using simplex method 
    rtcod = ekk_primalSimplex(test,2);

    int index[]={0}, table[]={0};

    // Analyze infeasibilities 
    rtcod = ekk_infeasibilities(test,8,1,index,table);

    // Print the solution 
    rtcod = ekk_printSolution(test);

    // Delete the model 
    rtcod = ekk_deleteModel(test);
  
    // OSL Destructor
    ekk_endContext(env); 
}
